# Hyper-Heuristic with Reinforcement Learning
This is an ongoing project as part of my PhD research, where I am implementing Reinforcement Learning agents for selecting low-level heuristics applied on combinatorial optimization problems.

# Implemented agents
* Deep Q-Network
* Dynamic Multi-Armed Bandit
* Fitness-Rate-Rank Multi Armed Bandit

# Combinatorial Problem Domains
The domains come from the [HyFlex Framework](http://www.asap.cs.nott.ac.uk/external/chesc2011/hyflex_description.html):
* Bin Packing
* MAX-SAT
* Personnel Scheduling
* Flow Shop
* Traveling Salesman
* Vehicle Routing
